#ifndef NBODYSIM_H
#define NBODYSIM_H

#include <string>

class nBodySim {
public:
    // constructor reads in data from datafile
    nBodySim(std::string& datafile);
    // destructor deletes arrays 
    ~nBodySim();
    // run simulation
    void runSimulation(double dt, unsigned nSteps);
    // loops over all pairs of particles and calculates forces, calculates current mean interparticle distance 
    void calculateForces();
    // loop over all pairs of particles and calculate mean interparticle distance
    double calculateMeanInterparticleDistance();
    // updates positions and velocities using the calculated forces
    void doTimeStep(double dt);
    // writes data to file, every row is a particle
    void write2file(const double* array, std::string filename, unsigned dim) const;

    // functions to get private variables
    double* getMasses() { return masses_; }
    double* getPositions() { return positions_; }
    double* getForces() { return forces_; }
    unsigned getNParticles() const { return nParticles_; }
    double getMeanInterparticleDistance() const { return meanInterparticleDistance_; }
private:
    unsigned nParticles_;
    // 3d vectors are stored as a array of length 3*nParticles_ in the format x1, y1, z1, x2, y2, z2, ...
    double* masses_;
    double* positions_;
    double* velocities_;
    double* softening_;
    double* potential_;
    double* forces_;
    double meanInterparticleDistance_;
};

#endif /* NBODYSIM_H */