#include <iostream>
#include <string>
#include <chrono>
#include "lib/nBodySim.hpp"

int main(int argc, char** argv) {
    std::string datafile;

    switch (argc) {
        case 1:
            datafile = "../data/data.ascii";
            break;
        case 2:
            datafile = argv[1];
            break;
        default:
            std::cerr << "Usage: " << argv[0] << " [datafile]" << std::endl;
            return 1;
    }

    double dt = 0.01;
    unsigned nSteps = 1000;

    nBodySim sim(datafile);
    unsigned N = sim.getNParticles();
    std::cout << "N = " << N << std::endl;

    double meanInterparticleDistance = sim.calculateMeanInterparticleDistance();
    std::cout << "Mean interparticle distance: " << meanInterparticleDistance << std::endl;

    /*
    for (unsigned i=0; i<N; ++i) {
        for (unsigned j=0; j<3; ++j) {
            std::cout << sim.getPositions()[3*i+j] << " ";
        }
        std::cout << std::endl;
    }
    */

    try {
        auto start = std::chrono::high_resolution_clock::now();
        // for (unsigned i=0; i<100; ++i)
            sim.calculateForces();
        auto stop = std::chrono::high_resolution_clock::now();

        auto duration = std::chrono::duration_cast<std::chrono::microseconds>(stop - start);
        std::cout << "Calculation Time: " << duration.count()/1000000.0 << " seconds" << std::endl;

        sim.write2file(sim.getForces(), "../data/output.txt", 3);
    } catch (std::exception& e) {
        std::cerr << e.what() << std::endl;
        return 1;
    }

    return 0;
}